Learn R Programming

CLSIEP15 (version 0.1.0)

calculate_df_combined: Calculate degrees of freedom of SE C (SE combined) given a selected scenario and additional parameters necessary for the scenario

Description

Calculate degrees of freedom of SE C (SE combined) given a selected scenario and additional parameters necessary for the scenario

Usage

calculate_df_combined(scenario, ...)

Value

DF

Arguments

scenario

Scenario (A, B, C, D, E)

...

additional parameters necessary for the scenario