Learn R Programming

CLSIEP15 (version 0.1.0)

calculate_se_rm: Calculate SE RM given a scenario and a list of additional args that can change based on the selected scenario or sub scenario

Description

Calculate SE RM given a scenario and a list of additional args that can change based on the selected scenario or sub scenario

Usage

calculate_se_rm(scenario, additional_args)

Value

SE RM

Arguments

scenario

scenario (A, B, C, D, E)

additional_args

additional arguments list