Learn R Programming

CLSIEP15 (version 0.1.0)

calculate_se_rm_a_Ucoverage: Calculate SE RM for scenario A when f the manufacturer supplies an “expanded uncertainty” (abbreviated by uppercase “U”) for the TV and coverage e.g. 95 or 99,

Description

Calculate SE RM for scenario A when f the manufacturer supplies an “expanded uncertainty” (abbreviated by uppercase “U”) for the TV and coverage e.g. 95 or 99,

Usage

calculate_se_rm_a_Ucoverage(U, coverage)

Value

SE RM

Arguments

U

expanded uncertainty

coverage

coverage