Learn R Programming

CLSIEP15 (version 0.1.0)

calculate_se_rm_a_Uk: Calculate SE RM for scenario A when f the manufacturer supplies an “expanded uncertainty” (abbreviated by uppercase “U”) for the TV and the “coverage factor” (abbreviated by “k”)

Description

Calculate SE RM for scenario A when f the manufacturer supplies an “expanded uncertainty” (abbreviated by uppercase “U”) for the TV and the “coverage factor” (abbreviated by “k”)

Usage

calculate_se_rm_a_Uk(U, k)

Value

SE RM

Arguments

U

expanded uncertainty

k

coverage factor