Learn R Programming

CLSIEP15 (version 0.1.0)

calculate_se_rm_scenario_d_e: Calculate SE RM for scenario D or E If the TV represents a conventional quantity value or When working with a commercial QC material supplied with a TV for which the standard error cannot be estimated

Description

Calculate SE RM for scenario D or E If the TV represents a conventional quantity value or When working with a commercial QC material supplied with a TV for which the standard error cannot be estimated

Usage

calculate_se_rm_scenario_d_e()

Arguments

Value

SE RM