calculate_df_combined: Calculate degrees of freedom of SE C (SE combined) given a selected scenario and additional parameters necessary for the scenario
Description
Calculate degrees of freedom of SE C (SE combined) given a selected scenario and additional parameters necessary for the scenario
Usage
calculate_df_combined(scenario, ...)
Arguments
- scenario
Scenario (A, B, C, D, E)
- ...
additional parameters necessary for the scenario